@@ -1,8 +1,9 @@
 use crate::mail::Mailer;
 
 pub fn send(mailer: &Mailer, to_email: &str, link: &str) {
-  let subject = "Reset Password Instructions)";
-  let text = format!(r#"
+    let subject = "Reset Password Instructions)";
+    let text = format!(
+        r#"
 (This is an automated message.)
 
 Hello,
@@ -10,8 +11,11 @@ Hello,
 Someone requested a password reset for the account associated with this email, but no account exists!
 If this was intentional, you can register for a new account using the link below:
 {link}
-"#, link=link);
-  let html = format!(r#"
+"#,
+        link = link
+    );
+    let html = format!(
+        r#"
 (This is an automated message.)
 
 Hello,
@@ -19,7 +23,9 @@ Hello,
 Someone requested a password reset for the account associated with this email, but no account exists!
 If this was intentional, you can register for a new account using the link below:
 {link}
-"#, link=link);
+"#,
+        link = link
+    );
 
-  mailer.send(to_email, &subject, &text, &html);
-}
\ No newline at end of file
+    mailer.send(to_email, &subject, &text, &html);
+}
